@@ -124,10 +124,10 @@ function(r,nfactors=1,residuals=FALSE,rotate="varimax",n.obs = NA, covar=FALSE,s
     result$weights <-  stats$weights
     result$r.scores <-  stats$r.scores
     if(!is.null(Phi) && oblique.scores) {
-                       Structure <- loadings %*% Phi} else {Structure <- loadings
+                       result$Structure <- loadings %*% Phi} else {result$Structure <- loadings
                        }
     
-    if(scores && raw) {result$scores <- factor.scores(scale(x.matrix),Structure,method=method)  # method = method added Nov 20, 2011
+    if(scores && raw) {result$scores <- factor.scores(scale(x.matrix),result$Structure,method=method)  # method = method added Nov 20, 2011
                 result$weights<- result$scores$weights
                 result$scores <- result$scores$scores}
     return(result)
@@ -147,4 +147,5 @@ function(r,nfactors=1,residuals=FALSE,rotate="varimax",n.obs = NA, covar=FALSE,s
   #modified December 21, 2011 to allow for finding the pc of covariances 
   #modified June 19, 2012 to fix a missing value problem reported by Neil Stewart
   #modified February 9, 2013 to label the type of rotation/transformation (as is documented but not implemented)
-  #modified February 25, 2013 to make scores=TRUE the default 
\ No newline at end of file
+  #modified February 25, 2013 to make scores=TRUE the default 
+  #modified 1/16/14 to output the structure matrix 
\ No newline at end of file
